@@ -43,12 +43,12 @@ package Astro::Coord::ECI::Moon;
 use strict;
 use warnings;
 
-our $VERSION = '0.042_02';
+our $VERSION = '0.047_01';
 
 use base qw{Astro::Coord::ECI};
 
 use Astro::Coord::ECI::Sun;	# Need for phase of moon calc.
-use Astro::Coord::ECI::Utils qw{:all};
+use Astro::Coord::ECI::Utils qw{ :all };
 use Carp;
 use POSIX qw{floor strftime};
 
@@ -78,12 +78,12 @@ my %static = (
     id => 'Moon',
     name => 'Moon',
     diameter => 3476,
-    );
+);
 
 my $weaken = eval {
     require Scalar::Util;
     Scalar::Util->can('weaken');
-    };
+};
 my $object;
 
 our $Singleton = $weaken;
@@ -114,7 +114,7 @@ otherwise.
 sub new {
     my ($class, @args) = @_;
     ref $class and $class = ref $class;
-    if ( $Singleton && $weaken && _classisa( $class, __PACKAGE__ ) ) {
+    if ( $Singleton && $weaken && __classisa( $class, __PACKAGE__ ) ) {
 	if ($object) {
 	    $object->set (@args) if @args;
 	    return $object;
@@ -135,6 +135,11 @@ This method produces almanac data for the Moon for the given location,
 between the given start and end times. The location is assumed to be
 Earth-Fixed - that is, you can't do this for something in orbit.
 
+The C<$location> argument may be omitted if the C<station> attribute has
+been set. That is, this method can also be called as
+
+ @almanac = $moon->almanac( $start, $end )
+
 The start time defaults to the current time setting of the $moon
 object, and the end time defaults to a day after the start time.
 
@@ -162,16 +167,11 @@ my @quarters = ('New Moon', 'First quarter Moon', 'Full Moon',
     'Last quarter Moon');
 
 sub almanac {
-    my $self = shift;
-    my $location = shift;
-    embodies($location, 'Astro::Coord::ECI') or
-	croak <<eod;
-Error - The first argument of the almanac() method must be a member of
-        the Astro::Coord::ECI class, or a subclass thereof.
-eod
-
-    my $start = shift || $self->universal;
-    my $end = shift || $start + 86400;
+    my ( $self, $location, $start, $end ) = __default_station( @_ );
+    defined $start
+	or $start = $self->universal();
+    defined $end
+	or $end = $start + SECSPERDAY;
 
     my @almanac;
 
@@ -225,15 +225,19 @@ sub almanac_hash {
 	    detail => $_->[2],
 	    description => $_->[3],
 	}
-    }, almanac(@_);
+    }, almanac( @_ );
 }
 
-=item $elevation = $tle->correct_for_refraction( $elevation )
+=item $elevation = $moon->correct_for_refraction( $elevation )
 
 This override of the superclass' method simply returns the elevation
 passed to it. Since the Moon has no atmosphere to speak of, there should
 be no diffraction to speak of either.
 
+See the L<Astro::Coord::ECI|Astro::Coord::ECI> C<azel()> and
+C<azel_offset()> documentation for whether this class'
+C<correct_for_refraction()> method is actually called by those methods.
+
 =cut
 
 sub correct_for_refraction {
@@ -543,7 +547,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2011 by Thomas R. Wyant, III
+Copyright (C) 2005-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
