@@ -50,7 +50,7 @@ package Astro::Coord::ECI::Sun;
 use strict;
 use warnings;
 
-our $VERSION = '0.042_02';
+our $VERSION = '0.047_01';
 
 use base qw{Astro::Coord::ECI};
 
@@ -97,7 +97,7 @@ otherwise.
 sub new {
     my ($class, @args) = @_;
     ref $class and $class = ref $class;
-    if ( $Singleton && $weaken && _classisa( $class, __PACKAGE__ ) ) {
+    if ( $Singleton && $weaken && __classisa( $class, __PACKAGE__ ) ) {
 	if ($object) {
 	    $object->set (@args) if @args;
 	    return $object;
@@ -118,6 +118,11 @@ This method produces almanac data for the Sun for the given location,
 between the given start and end times. The location is assumed to be
 Earth-Fixed - that is, you can't do this for something in orbit.
 
+The C<$location> argument may be omitted if the C<station> attribute has
+been set. That is, this method can also be called as
+
+ @almanac = $sun->almanac( $start, $end )
+
 The start time defaults to the current time setting of the $sun
 object, and the end time defaults to a day after the start time.
 
@@ -150,16 +155,11 @@ my @quarters = ('Spring equinox', 'Summer solstice', 'Fall equinox',
 	'Winter solstice');
 
 sub almanac {
-    my $self = shift;
-    my $location = shift;
-    embodies ($location, 'Astro::Coord::ECI') or
-	croak <<eod;
-Error - The first argument of the almanac() method must be a member of
-        the Astro::Coord::ECI class, or a subclass thereof.
-eod
-
-    my $start = shift || $self->universal;
-    my $end = shift || $start + 86400;
+    my ( $self, $location, $start, $end ) = __default_station( @_ );
+    defined $start
+	or $start = $self->universal();
+    defined $end
+	or $end = $start + SECSPERDAY;
 
     my @almanac;
 
@@ -226,6 +226,10 @@ photosphere or anywhere else in the environs of the Sun, and explaining
 why I make no correction at all seemed easier than explaining why I make
 an incorrect correction.
 
+See the L<Astro::Coord::ECI|Astro::Coord::ECI> C<azel()> and
+C<azel_offset()> documentation for whether this class'
+C<correct_for_refraction()> method is actually called by those methods.
+
 =cut
 
 sub correct_for_refraction {
@@ -534,7 +538,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2011 by Thomas R. Wyant, III
+Copyright (C) 2005-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
