@@ -121,7 +121,7 @@ use warnings;
 
 use base qw{Astro::Coord::ECI::TLE};
 
-our $VERSION = '0.042_02';
+our $VERSION = '0.047_01';
 
 use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils qw{:all};
@@ -320,6 +320,12 @@ satellite at the given station between the given start time and the
 given end time. This list may be empty. If called in scalar context you
 get the number of flares.
 
+All arguments are optional, with the defaults being
+
+ $station = the 'station' attribute
+ $start = time()
+ $end = $start + 1 day
+
 Each flare is represented by a reference to an anonymous hash, with
 elements as follows:
 
@@ -394,9 +400,10 @@ flares are calculated by a fairly arbitrary equation whose coefficients
 were fitted to visual flare magnitude estimates collected by Ron Lee
 and made available on the Web by Randy John as part of his skysat
 web site at L<http://home.comcast.net/~skysat/>. Atmospheric extinction
-is also taken into account for the non-specular flares. Atmospheric
-extinction is calculated according to the article by Daniel W.
-Green in the July 1992 issue of "International Comet Quarterly", and
+is also taken into account for the non-specular flares.
+
+Atmospheric extinction is calculated according to the article by Daniel
+W.  Green in the July 1992 issue of "International Comet Quarterly", and
 available at L<http://www.cfa.harvard.edu/icq/ICQExtinct.html>. Because
 Heavens Above does not display flares dimmer than a certain magnitude
 (-6 for day flares, and apparently 0 for night flares), it may not
@@ -409,7 +416,7 @@ Second, I suspect that the positions and velocities calculated by
 Astro::Coord::ECI::TLE differ slightly from those used by Heavens Above.
 I do not know this, because I do not know what positions Heavens Above
 uses, but there are slight differences among the results of all the
-orbital propagation models I have looked at.  All I can say about the
+orbital propagation models I have looked at. All I can say about the
 accuracy of Astro::Coord::ECI::TLE is that it duplicates the test data
 given in "Spacetrack Report Number Three". But small differences are
 important -- 0.1 degree at the satellite can make the difference between
@@ -481,7 +488,7 @@ use constant PM_START_LIMIT => 43200 - 480;	# 8 minutes before noon.
 use constant PM_END_LIMIT => 480;		# 8 minutes after midnight.
 
 sub flare {
-    my ($self, @args) = @_;
+    my ( $self, @args ) = __default_station( @_ );
     my $method = $self->{&ATTRIBUTE_KEY}{_algorithm_method};
     return $self->$method (@args);
 }
@@ -492,12 +499,12 @@ sub _flare_fixed {
     my $station = shift;
     {
 	local $@;
-	_instance( $station, 'Astro::Coord::ECI' ) or croak <<eod;
+	__instance( $station, 'Astro::Coord::ECI' ) or croak <<eod;
 Error - The station must be a subclass of Astro::Coord::ECI.
 eod
     }
     my $start = shift || time ();
-    my $end = shift || $start + 86400;
+    my $end = shift || $start + SECSPERDAY;
     $end >= $start or croak <<eod;
 Error - End time must be after start time.
 eod
@@ -627,6 +634,8 @@ eod
 
 
 #	See if the satellite is illuminated at this time.
+#	TODO This code may need some slop; specifically we might want to
+#	assume the Sun is higher than it actually is by $max_angle.
 
 	    ($self->universal ($time)->azel ($illum->universal ($time)))[1] >=
 		$self->dip () or next;
@@ -639,9 +648,9 @@ eod
 #	the X axis. The method returns Math::VectorReal objects
 #	corresponding to all inputs, including '$self'.
 
-	    my ($tle_vector, $illum_vector, $station_vector) =
+	    my ( $illum_vector, $station_vector ) =
 		$self->_flare_transform_coords_list (
-		$illum, $station->universal ($time));
+		$illum, $station->universal( $time ) );
 
 
 #	Now we do a second iteration over the Main Mission Antennae,
@@ -658,8 +667,8 @@ eod
 		my $illum_vector = [@$illum_vector];
 		my $station_vector = [@$station_vector];
 		next unless defined (
-		    my $angle = _flare_calculate_angle_list ($tle_vector,
-		    $mma, $illum_vector, $station_vector));
+		    my $angle = _flare_calculate_angle_list(
+		    $mma, $illum_vector, $station_vector ) );
 
 
 #	Save the angle, time, and cloned station for subsequent
@@ -754,18 +763,18 @@ MMA_LOOP:
 #	motion (and hence one of the Main Mission Antennae) is along
 #	the X axis.
 
-		my ($tle_vector, $illum_vector, $station_vector) =
-		    $self->universal ($time)->
-			_flare_transform_coords_list (
-			$illum->universal ($time),
-			$station->universal ($time));
+		my ( $illum_vector, $station_vector ) =
+		    $self->universal( $time )->
+			_flare_transform_coords_list(
+			$illum->universal( $time ),
+			$station->universal( $time ) );
 
 
 #	Calculate the angle between the satellite and the reflection
 #	of the Sun, as seen by the observer.
 
-		my $angle = _flare_calculate_angle_list ($tle_vector,
-		    $mma, $illum_vector, $station_vector);
+		my $angle = _flare_calculate_angle_list(
+		    $mma, $illum_vector, $station_vector );
 		defined $angle or next MMA_LOOP;
 
 
@@ -796,6 +805,10 @@ MMA_LOOP:
 #	is not quite lit. This happened with Iridium 32 (OID 24945) on
 #	Feb 03 2007 at 07:45:19 PM. So we check for illumination one
 #	last time.
+#	TODO: this calculation should be performed not on the position
+#	of the Sun, but on the actual point on the Sun which is
+#	reflected to the observer. It looks now like it needs to be done
+#	in _flare_calculate_angle_list().
 
 	    ($self->universal ($time)->azel ($illum->universal ($time)))[1] >=
 		$self->dip () or next;
@@ -846,12 +859,12 @@ sub _flare_entrance {
 	$start, $end,
 	sub {
 	    $self->universal ($_[0]);
-	    my ($tle_vector, $illum_vector, $station_vector) =
-		$self->_flare_transform_coords_list (
-		$illum->universal ($_[0]),
-		$station->universal ($_[0]));
-	    if (defined (my $angle = _flare_calculate_angle_list ($tle_vector,
-		$mma, $illum_vector, $station_vector))) {
+	    my ( $illum_vector, $station_vector ) =
+		$self->_flare_transform_coords_list(
+		$illum->universal( $_[0] ),
+		$station->universal( $_[0] ) );
+	    if ( defined ( my $angle = _flare_calculate_angle_list(
+		$mma, $illum_vector, $station_vector ) ) ) {
 		$output = [$angle, $_[0], $illum_vector, $station_vector];
 		1;
 	    } else {
@@ -860,12 +873,12 @@ sub _flare_entrance {
 	});
     $output ||= do {	# Can happen if end is entrance.
 	    $self->universal ($end);
-	    my ($tle_vector, $illum_vector, $station_vector) =
-		$self->_flare_transform_coords_list (
-		$illum->universal ($end),
-		$station->universal ($end));
-	    my $angle = _flare_calculate_angle_list ($tle_vector,
-		$mma, $illum_vector, $station_vector);
+	    my ( $illum_vector, $station_vector ) =
+		$self->_flare_transform_coords_list(
+		$illum->universal( $end ),
+		$station->universal( $end) );
+	    my $angle = _flare_calculate_angle_list(
+		$mma, $illum_vector, $station_vector );
 	    defined $angle ?
 		[$angle, $end, $illum_vector, $station_vector] :
 		undef;
@@ -879,7 +892,7 @@ eod
     return $output;
 }
 
-#	@vectors = $tle->_flare_transform_coords_list ($eci ....)
+#	@vectors = $tle->_flare_transform_coords_list( $eci ....)
 #
 #	This private method transforms the coordinates of the $tle
 #	object and all $eci objects passed in, so that the $tle
@@ -890,42 +903,67 @@ eod
 #	nominally "up and down", with the center of the Earth in the
 #	- Z direction. The objects are not modified, instead
 #	list references (containing the position vectors)
-#	corresponding to all arguments (including $tle) are returned.
+#	corresponding to all arguments (except the invocant) are
+#	returned.
 
 sub _flare_transform_coords_list {
-    my @args = @_;
-    my @ref = $args[0]->eci ();
-    my $X = vector_unitize ([@ref[3 .. 5]]);
-    my $Y = vector_cross_product (vector_unitize ([@ref[0 .. 2]]), $X);
-    my $Z = vector_cross_product ($X, $Y);
+    my ( $self, @args ) = @_;
+    my @ref = $self->eci();
+    my $X = vector_unitize( [@ref[3 .. 5]] );
+    my $Y = vector_cross_product( vector_unitize( [ @ref[0 .. 2]] ), $X );
+    my $Z = vector_cross_product( $X, $Y );
     my @coord = ($X, $Y, $Z);
     my @rslt;
     foreach my $loc (@args) {
-	my @eci = $loc->eci ();
-	my $pos = [$eci[0] - $ref[0], $eci[1] - $ref[1], $eci[2] - $ref[2]];
-	foreach my $inx (0 .. 2) {
-	    $eci[$inx] = vector_dot_product ($pos, $coord[$inx])
-	}
-	push @rslt, [@eci[0 .. 2]];
+	my @eci = $loc->eci();
+	my @pos = map { $eci[$_] - $ref[$_] } 0 .. 2;
+	push @rslt, [
+	    map { vector_dot_product( \@pos, $coord[$_] ) } 0 .. 2
+	];
+    }
+    return @rslt;
+}
+
+#	@original = $tle->_flare_transform_coords_inverse_list( @vectors )
+#
+#	This private method is the inverse (almost) of
+#	_flare_transform_coords_list(). The weasel word is because it
+#	returns array references representing the ECI position vectors,
+#	rather than Astro::Coord::ECI objects.
+
+sub _flare_transform_coords_inverse_list {
+    my ( $self, @args ) = @_;
+    my @ref = $self->eci();
+    my $X = vector_unitize( [@ref[3 .. 5]] );
+    my $Y = vector_cross_product( vector_unitize( [ @ref[0 .. 2]] ), $X );
+    my $Z = vector_cross_product( $X, $Y );
+    my @coord = _invert_matrix_list($X, $Y, $Z);
+    my @rslt;
+    foreach my $loc (@args) {
+	push @rslt, [
+	    map { vector_dot_product( $loc, $coord[$_] ) + $ref[$_] } 0 .. 2
+	];
     }
     return @rslt;
 }
 
 
-#	$angle = _flare_calculate_angle_list ($tle, $mma, $illum, $station)
+#	$angle = _flare_calculate_angle_list($mma, $illum, $station)
 
 #	This private subroutine calculates the angle between the
 #	satellite and the reflection of the Sun in the given Main
-#	Mission Antenna as seen from the observing station. All objects
-#	are assumed to be list references generated by
-#	_flare_transform_coords_list ().
+#	Mission Antenna as seen from the observing station. $illum and
+#	$station are list reverences generated by
+#	_flare_transform_coords_list(). The satellite position is not
+#	needed because in this coordinate system it is [0, 0, 0]
 
 #	A reflection can only occur if both the Sun and the observer
-#	are in front of the antenna (i.e. have positive Z coordinates).
-#	If there is no reflection, undef is returned.
+#	are in front of the antenna (i.e. have positive Z coordinates
+#	after transforming everything so that the plane of the MMA is
+#	the X-Y axis). If there is no reflection, undef is returned.
 
 sub _flare_calculate_angle_list {
-    my ($tle, $mma, $illum, $station) = @_;
+    my ( $mma, $illum, $station ) = @_;
 
 #	Rotate the objects so that the Main Mission Antenna of interest
 #	lies in the X-Y plane, facing in the +Z direction.
@@ -946,7 +984,7 @@ sub _flare_calculate_angle_list {
 #	Now calculate the angle between the illumination source and the
 #	observer as seen by the observer.
 
-    return _list_angle ($station, $illum, $tle);
+    return _list_angle( $station, $illum, [ 0, 0, 0 ] );
 }
 
 
@@ -1164,52 +1202,35 @@ my $sun_angle = $station->angle ($sun, $self);
 
 my ($virtual_image, $image_vector) = do {
 
-#	    Recover the position of the virtual image of the
-#	    illuminator. We calculated this before, but never saved it.
+    # Recover the position of the virtual image of the illuminator. We
+    # calculated this before, but never saved it.
 
-    my @eci;
-    foreach my $inx (0 .. 2) {
-	$eci[$inx] = vector_dot_product ($illum_vector, $transform_vector[$mma][$inx]);
-	}
-    $eci[2] = - $eci[2];
-    my $image_vector = [@eci];
+    my $image_vector = [
+	map { vector_dot_product( $illum_vector,
+	    $transform_vector[$mma][$_] ) } 0 .. 2
+    ];
+    $image_vector->[2] = - $image_vector->[2];
 
 
-#	    Undo the rotations that placed the MMA of interest in the
-#	    X-Y plane.
+    # Undo the rotations that placed the MMA of interest in the X-Y
+    # plane.
 
-    foreach my $inx (0 .. 2) {
-	$eci[$inx] = vector_dot_product ($image_vector,
-		$inverse_transform_vector[$mma][$inx]);
-	}
-    $image_vector = [@eci];
+    $image_vector = [
+	map { vector_dot_product( $image_vector,
+	    $inverse_transform_vector[$mma][$_] ) } 0 .. 2
+    ];
 
 
-#	    Recover the rotation that placed the satellite vertical,
-#	    facing in the X direction.
+    # Transform from satellite-local coordinates to ECI coordinates.
 
-    my @ref = $self->eci ();
-    my $X = vector_unitize ([@ref[3 .. 5]]);
-    my $Y = vector_cross_product (vector_unitize ([@ref[0 .. 2]]), $X);
-    my $Z = vector_cross_product ($X, $Y);
+    ( $image_vector ) = $self->_flare_transform_coords_inverse_list(
+	$image_vector );
 
-#	    Invert this to get the reverse rotation.
+    # Manufacture an object representing the virtual image, and a vector
+    # represnting same for use in calculating the flare sub-point.
 
-    my @coord = _invert_matrix_list ($X, $Y, $Z);
-
-#	    Recover the ECI coordinates of the virtual image of the
-#	    illuminator.
-
-    foreach my $inx (0 .. 2) {
-	$eci[$inx] = vector_dot_product ($image_vector, $coord[$inx]) + $ref[$inx];
-	}
-
-#	    Manufacture an object representing the virtual image, and
-#	    a vector represnting same for use in calculating the flare
-#	    sub-point.
-
-    (Astro::Coord::ECI->universal ($time)->eci (@eci),
-	\@eci);
+    ( Astro::Coord::ECI->universal( $time )->eci( @{ $image_vector } ),
+	$image_vector );
     };
 
 
@@ -1433,8 +1454,8 @@ sub _reflection_fixed {
 #	motion (and hence one of the Main Mission Antennae) is along
 #	the X axis.
 
-    my ($tle_vector, $illum_vector, $station_vector) =
-	$self->_flare_transform_coords_list ($illum, $station);
+    my ( $illum_vector, $station_vector ) =
+	$self->_flare_transform_coords_list( $illum, $station );
 
     my @rslt;
 
@@ -1445,8 +1466,8 @@ sub _reflection_fixed {
 #	as seen by the observer. We skip to the next antenna if no
 #	reflection is generated.
 
-	my $angle = _flare_calculate_angle_list (
-		$tle_vector, $mma, $illum_vector, $station_vector);
+	my $angle = _flare_calculate_angle_list(
+		$mma, $illum_vector, $station_vector );
 	warn <<eod if $debug;	## no critic (RequireCarping)
         MMA $mma Angle: @{[defined $angle ? rad2deg ($angle) . ' degrees' :
 		'undefined']}
@@ -1643,7 +1664,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2011 by Thomas R. Wyant, III
+Copyright (C) 2005-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
