@@ -140,7 +140,7 @@ our @CARP_NOT = qw{
     Astro::Coord::ECI
 };
 
-our $VERSION = '0.042_02';
+our $VERSION = '0.047_01';
 
 use constant ERR_NOCURRENT => <<eod;
 Error - Can not call %s because there is no current member. Be
@@ -196,11 +196,11 @@ sub add {
 	defined $effective or $effective = $tle->get('epoch');
 	$ep{$effective} = $tle;
     }
-    foreach my $tle (map {_instance( $_, __PACKAGE__ ) ?
+    foreach my $tle (map {__instance( $_, __PACKAGE__ ) ?
 	    $_->members : $_} @args) {
 	my $aid = $tle->get ('id');
 	if (defined $id) {
-	    _instance( $tle, $class ) or croak <<eod;
+	    __instance( $tle, $class ) or croak <<eod;
 Error - Additional member of @{[__PACKAGE__]} must be a
         subclass of $class
 eod
@@ -209,7 +209,7 @@ Error - NORAD ID mismatch. Trying to add ID $aid to set defined
         as ID $id.
 eod
 	} else {
-	    _instance( $tle, 'Astro::Coord::ECI::TLE' ) or croak <<eod;
+	    __instance( $tle, 'Astro::Coord::ECI::TLE' ) or croak <<eod;
 Error - First member of @{[__PACKAGE__]} must be a subclass
         of Astro::Coord::ECI::TLE.
 eod
@@ -355,7 +355,7 @@ effective date.
 
 sub members {
     my $self = shift;
-    return map {$_->[1]} @{$self->{members}};
+    return ( map { $_->[1] } @{ $self->{members} } );
 }
 
 =item $set->represents($class)
@@ -595,7 +595,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2011 by Thomas R. Wyant, III
+Copyright (C) 2005-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
